
/*---------------------------------------------------------------*/
/* File contains SQL statements to upgrade all previous releases'*/
/* database tables to a newer release's version.  The file is    */
/* required for upgrade to make sure customizations aren't lost. */
/* It is cumulative with everything new or changed since 3.5.    */
/*                                                               */
/* NOTES:                                                        */
/* January 2007                                                  */
/* In ITM 6.1 fix packs only the inserts for changed or new      */
/* situations were placed in this file.  Starting in 6.2 the     */
/* UPDATEs were added to modify all existing tables for changes  */
/* and support for upgrade from 3.5 was added.                   */
/*                                                               */
/* July 2007                                                     */
/* In ITM 6.2 it was discovered that two situations had names    */
/* that were too long.  TEPS changes starting erroring them out  */
/* because of a name length check they added.  So the following  */
/* things were done in this file:                                */
/* - Left the updates and changes for the old situations named   */
/*   OS400_Job_Avg_Response_Time_High and                        */
/*   OS400_Communications_Line_Failed and did not delete them.   */
/* - Added inserts for the new situations named                  */
/*   OS400_Job_AvgResponse_Time_High and                         */
/*   OS400_Communication_Line_Failed                             */
/*                                                               */
/*---------------------------------------------------------------*/

/*---------------------------------------------------------------*/
/* Table O4SRV.CCT, Take Action command table.                   */
/*---------------------------------------------------------------*/

/* NAME is English, not resource bundle key, for 6.2.1 only */
/* See defect 82133. */
UPDATE O4SRV.CCT SET DESC="Ka4:KA41466", NAME="Send Break Message"
 WHERE KEY="0980501101856000TESTERMenu";      

/*---------------------------------------------------------------*/
/* Table O4SRV.TACTYPCY, Policy activities table.                */
/*---------------------------------------------------------------*/

/* changed too-long-named situation so change this reference     */

UPDATE O4SRV.TACTYPCY SET ACTINFO="OS400_Communication_Line_Failed"
 WHERE PCYNAME = "OS400_Comm_Critical_Message" AND ACTNAME = "A4247";

/*---------------------------------------------------------------*/
/* Table O4SRV.TMANTMPL, obsolete table from OMEGAMON.           */
/*---------------------------------------------------------------*/

/* No inserts nor updates needed as of ITM 6.2 GA */

/*---------------------------------------------------------------*/
/* Table O4SRV.TOBJACCL, Situation activation table.             */
/*---------------------------------------------------------------*/

/* Work around situation OS400_Comm_FunctnChk_Workaround no longer */
/* needed and was deleted in ITM 6.1 Fixpack 2                     */ 

DELETE FROM O4SRV.TOBJACCL 
   WHERE OBJNAME = "OS400_Comm_FunctnChk_Workaround";

/* Updates for 3.5 situations */

/* Delete the bad version of the table, if there, for 3.5  */
DELETE FROM O4SRV.TOBJACCL WHERE NODEL = "*OS400_OM" AND OBJNAME = "OS40
0_Adress_Critical" AND OBJCLASS = "5140";

/* Insert the good version of the table, if not there already  */
INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Address_Critical",
   "Y",
   "1061023112154000",
   "",
   "IBM",
   "5140",
   "5535"
  );

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Address_Critical"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "",
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_CPU_Util_Warning"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Comm_IOP_Util_Warning"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Communications_Line_Failed" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Disk_Capacity_Critical"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Disk_IOP_Util_Warning" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Disk_Util_Critical"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Disk_Util_Warning"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Interactive_Jobs_CPU_High"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Job_Avg_Response_Time_High" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="", 
      LSTDATE = "",
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Network_Attribute_Changed" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_OMA_Message_Log" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Perm_Addresses_Warning"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "",
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Pool_Faulting_Warning" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Pool_Transitions_High"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Snads_Critical"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="", 
      LSTDATE = "",
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Snads_Ended"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Snads_Job_Missing"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "",
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Snads_Router_Failed"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_System_ASP_Warning"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_System_Value_Changed"  
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8)	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

UPDATE O4SRV.TOBJACCL 
  SET LSTRELEASE="",
      LSTDATE = "", 
      LSTUSRPRF="IBM"
  WHERE
      OBJNAME="OS400_Temp_Addresses_Warning" 
      AND SYSTEM.PARMA("QIBUSER", "SYSADMIN", 8) 	 
      AND SYSTEM.PARMA("QIBCLASSID","5535",4);	 

/* Insert situations new since 3.5 */

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_ASP_Nearing_Capacity",
   "Y",
   "1060928145621000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_ASP_Overflow_Warning",
   "Y",
   "1060928150451000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Aux_Stor_Near_Guidelines",
   "Y",
   "1060928155543000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Aux_Stor_Over_Guidelines",
   "Y",
   "1060928155644000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_CPU_Guidelines_Warning",
   "Y",
   "1060928151357000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Disk_Mirroring_Not_Active",
   "Y",
   "1060928140530000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Interactive_Feature_CPU",
   "Y",
   "1060928151739000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Job_Queue_Not_Active",
   "Y",
   "1060928153049000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Job_Queue_Not_Assigned",
   "Y",
   "1060928153257000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Management_Central_Events",
   "Y",
   "1060928172129000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Output_Queue_No_Writer",
   "Y",
   "1060928154726000",
   "",
   "IBM",
   "5140",
   "5535"
  );

/*---------------------------------------------------------------*/
/* Insert the two situations which had their names shortened     */
/* for release 6.2.  (see note in prolog for details)            */
/*---------------------------------------------------------------*/

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Communication_Line_Failed",
   "Y",
   "0961111010101000",
   "",
   "IBM",
   "5140",
   "5535"
  );

INSERT INTO O4SRV.TOBJACCL
  (NODEL,
   OBJNAME,
   HUB,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJCLASS,
   QIBCLASSID)
VALUES
  ("*OS400_OM",
   "OS400_Job_AvgResponse_Time_High",
   "Y",
   "0961111010101000",
   "",
   "IBM",
   "5140",
   "5535"
  );

/*---------------------------------------------------------------*/
/* Table O4SRV.TPCYDESC, Policy definition table.                */
/*---------------------------------------------------------------*/

UPDATE O4SRV.TPCYDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", TEXT="Ka4:KA41441"
   WHERE PCYNAME="OS400_Address_Critical_Message"; 

UPDATE O4SRV.TPCYDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", TEXT="Ka4:KA41442"
   WHERE PCYNAME="OS400_Comm_Critical_Message"; 

UPDATE O4SRV.TPCYDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", TEXT="Ka4:KA41443"
   WHERE PCYNAME="OS400_High_CPU_Message"; 

UPDATE O4SRV.TPCYDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", TEXT="Ka4:KA41444"
   WHERE PCYNAME="OS400_Snads_Critical_Message"; 


/*---------------------------------------------------------------*/
/* Table O4SRV.TSITDESC, Situation description table.            */
/*---------------------------------------------------------------*/

/* Work around situation OS400_Comm_FunctnChk_Workaround is no   */
/* longer needed and was deleted in ITM 6.1 Fixpack 2.  It was   */
/* first shipped in ITM 6.1 GA.                                  */ 

DELETE FROM O4SRV.TSITDESC 
   WHERE SITNAME = "OS400_Comm_FunctnChk_Workaround";

/* Update rows from 3.5 */

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41418"
   WHERE SITNAME ="OS400_Address_Critical"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', QIBSCOPE="E", 
   SITINFO="SEV=Critical", TEXT="Ka4:KA41420"
   WHERE SITNAME ="OS400_Comm_IOP_Util_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41421"
   WHERE SITNAME ="OS400_Communications_Line_Failed"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41419"
   WHERE SITNAME ="OS400_CPU_Util_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', QIBSCOPE="E", 
   SITINFO="SEV=Critical;ATOM=KA4DISK.ARMNUMBER",
   TEXT="Ka4:KA41422"
   WHERE SITNAME ="OS400_Disk_Capacity_Critical"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', QIBSCOPE="E", 
   SITINFO="SEV=Warning", TEXT="Ka4:KA41423"
   WHERE SITNAME ="OS400_Disk_IOP_Util_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical;ATOM=KA4DISK.ARMNUMBER",
   TEXT="Ka4:KA41424"
   WHERE SITNAME ="OS400_Disk_Util_Critical"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning;ATOM=KA4DISK.ARMNUMBER", 
   TEXT="Ka4:KA41425"
   WHERE SITNAME ="OS400_Disk_Util_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41426"
   WHERE SITNAME ="OS400_Interactive_Jobs_CPU_High"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41427"
   WHERE SITNAME ="OS400_Job_Avg_Response_Time_High"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41428"
   WHERE SITNAME ="OS400_Network_Attribute_Changed"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41429"
   WHERE SITNAME ="OS400_OMA_Message_Log"; 

/* Changed autostart values in the following for 6.2 GA, */
/* but this update does not include the change.  The     */
/* customer chooses the autostart value so we leave it.  */

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41430"
   WHERE SITNAME ="OS400_Perm_Addresses_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41431"
   WHERE SITNAME ="OS400_Pool_Faulting_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41432"
   WHERE SITNAME ="OS400_Pool_Transitions_High"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41433"
   WHERE SITNAME ="OS400_Snads_Critical"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41434"
   WHERE SITNAME ="OS400_Snads_Ended"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   AFFINITIES="2000000000000000000000000000000000000000000",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41435"
   WHERE SITNAME ="OS400_Snads_Job_Missing"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41436"
   WHERE SITNAME ="OS400_Snads_Router_Failed"; 

/* Condition attribute changed for OS400_System_ASP_Warning situation*/

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41437",
   PDT="*IF *VALUE OS400_System_Status.System_ASP_Used *GE 90"
   WHERE SITNAME ="OS400_System_ASP_Warning"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Critical", TEXT="Ka4:KA41438"
   WHERE SITNAME ="OS400_System_Value_Changed"; 

UPDATE O4SRV.TSITDESC 
   SET LSTRELEASE="", LSTUSRPRF="IBM", LSTCCSID="",
   ADVISE='ADVICE("ka4:"+$ISITSTSH.SITNAME$);', 
   QIBSCOPE="E", SITINFO="SEV=Warning", TEXT="Ka4:KA41439"
   WHERE SITNAME ="OS400_Temp_Addresses_Warning"; 

  
/* ITM 6.2 GA new situations. */

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*YES",
   "",
   "",
   "1060928174018000",
   "",
   "IBM",
   "",
   "*IF *VALUE i5OS_Auxiliary_Storage_Pool.Utilization_Percent *GE 80.0"
,
   "E",
   "0",
   "010000",
   "*NONE",
   "OS400_ASP_Nearing_Capacity",
   "Ka4:KA41532",
   "NNY",
   "SEV=Warning;ATOM=KA4ASP.ASPNUMBER",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
  

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928154820000",
   "",
   "IBM",
   "",
   "*IF *VALUE i5OS_Auxiliary_Storage_Pool.Overflow_Storage *GT 0 *AND *
VALUE i5OS_Auxiliary_Storage_Pool.Status *EQ VARIED_ON",
   "E",
   "1",
   "000030",
   "*NONE",
   "OS400_ASP_Overflow_Warning",
   "Ka4:KA41533",
   "NNY",
   "SEV=Warning;ATOM=KA4ASP.ASPNUMBER",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928155551000",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_System_Status.%_Aux_Storage_Used *GE 80.0",
   "E",
   "0",
   "010030",
   "*NONE",
   "OS400_Aux_Stor_Near_Guidelines",
   "Ka4:KA41540",
   "NNY",
   "SEV=Warning",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928155702000",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_System_Status.%_Aux_Storage_Used *GE 90.0",
   "E",
   "0",
   "010030",
   "*NONE",
   "OS400_Aux_Stor_Over_Guidelines",
   "Ka4:KA41541",
   "NNY",
   "SEV=Warning",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928155014000",
   "",
   "IBM",
   "",
   "*IF ( ( *VALUE OS400_System_Status.CPU_Percent *GE 85.0 *AND *VALUE 
OS400_System_Status.Processing_Capacity *LE 1.0 ) *OR ( *VALUE OS400_Sys
tem_Status.CPU_Percent *GE 88.0 *AND *VALUE OS400_System_Status.Processi
ng_Capacity *GT 1.0 *AND *VALUE OS400_System_Status.Processing_Capacity 
*LE 2.0 ) *OR ( *VALUE OS400_System_Status.CPU_Percent *GE 91.0 *AND *VA
LUE OS400_System_Status.Processing_Capacity *GT 2.0 *AND *VALUE OS400_Sy
stem_Status.Processing_Capacity *LE 3.0 ) *OR ( *VALUE OS400_System_Stat
us.CPU_Percent *GE 95.0 *AND *VALUE OS400_System_Status.Processing_Capac
ity *GT 3.0 ) )",
   "E",
   "0",
   "001500",
   "*NONE",
   "OS400_CPU_Guidelines_Warning",
   "Ka4:KA41534",
   "NNY",
   "SEV=Warning;COUNT=2",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
 
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928150028000",
   "",
   "IBM",
   "",
   "*IF *VALUE i5OS_Disk.Mirror_Status *NE NA *AND *VALUE i5OS_Disk.Stat
us *NE Not_configured *AND *VALUE i5OS_Disk.Mirror_Status *NE Active",
   "E",
   "0",
   "003000",
   "*NONE",
   "OS400_Disk_Mirroring_Not_Active",
   "Ka4:KA41542",
   "NNY",
   "ATOM=KA4DISKI5.NAME",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#y000000000",
   "",
   "*NO",
   "",
   "",
   "1060928151804000",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_System_Status.%_Interactive_Limit *GE 90.0",
   "E",
   "0",
   "001500",
   "*NONE",
   "OS400_Interactive_Feature_CPU",
   "Ka4:KA41535",
   "NNY",
   "SEV=Warning",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000##000000000",
   "",
   "*NO",
   "",
   "",
   "1060928155050000",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_Job_Queue.Number_Jobs *GE 1 *AND *VALUE OS400_Job_Q
ueue.Status *NE 'RELEASED'",
   "E",
   "0",
   "010000",
   "*NONE",
   "OS400_Job_Queue_Not_Active",
   "Ka4:KA41536",
   "NNY",
   "SEV=Warning;ATOM=KA4JOBQ.NAME",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000##000000000",
   "",
   "*NO",
   "",
   "",
   "1060928155103000",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_Job_Queue.Number_Jobs *GE 1 *AND *VALUE OS400_Job_Q
ueue.Subsystem *EQ '          '",
   "E",
   "0",
   "010030",
   "*NONE",
   "OS400_Job_Queue_Not_Assigned",
   "Ka4:KA41537",
   "NNY",
   "SEV=Warning;ATOM=KA4JOBQ.NAME",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#m000000000",
   "",
   "*NO",
   "",
   "",
   "1060928172215000",
   "",
   "IBM",
   "",
   "*IF *COUNT i5OS_Management_Central.ORIGINNODE *GT 0",
   "E",
   "0",
   "000000",
   "*NONE",
   "OS400_Management_Central_Events",
   "Ka4:KA41538",
   "NNY",
   "SEV=Warning;ATOM=KA4MGTCNT.DATETIME",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000#m000000000",
   "",
   "*NO",
   "",
   "",
   "1060928154757000",
   "",
   "IBM",
   "",
   "*IF *VALUE i5OS_Output_Queue.Files *GE 1 *AND *VALUE i5OS_Output_Que
ue.Writers *LE 0",
   "E",
   "0",
   "010030",
   "*NONE",
   "OS400_Output_Queue_No_Writer",
   "Ka4:KA41539",
   "NNY",
   "SEV=Warning;ATOM=KA4OUTPUTQ.NAME",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

/*---------------------------------------------------------------*/
/* Insert the two situations which had their names shortened     */
/* for release 6.2.  (see note in prolog for details)            */
/*---------------------------------------------------------------*/

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000##000000000",
   "*NO",
   "*NO",
   "Y",
   "",
   "1050706154529004",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_Message.ID *EQ CPA58CC *OR *VALUE OS400_Message.ID 
   *EQ CPA58CD",
   "E",
   "0",
   "001500",
   "*NONE",
   "OS400_Communication_Line_Failed",
   "Ka4:KA41421",
   "NN",
   "SEV=Critical",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("20000000000000000000000000000000##000000000",
   "*NO",
   "*NO",
   "Y",
   "",
   "1050706154530004",
   "",
   "IBM",
   "",
   "*IF *VALUE OS400_Job.Type *EQ *INT *AND *AVG OS400_Job.Response_Time
   *GE 5",
   "E",
   "0",
   "000500",
   "*NONE",
   "OS400_Job_AvgResponse_Time_High",
   "Ka4:KA41427",
   "NN",
   "SEV=Critical",
   'ADVICE("ka4:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

/*---------------------------------------------------------------*/
/* Table O4SRV.TTMPLSIT, Template status table. Obsolete.        */
/*---------------------------------------------------------------*/

/* No inserts nor updates needed as of ITM 6.2 GA */

/*---------------------------------------------------------------*/
/* Table O4SRV.TTMPLSTA, Template state table. Obsolete.         */
/*---------------------------------------------------------------*/

/* No inserts nor updates needed as of ITM 6.2 GA */
